# ZIMFuzzySearch Highlighter

## Short Description

Client side fuzzy search combined with seperate configurable result highlighting.

Files from src/lib are compiled to lib folder on root lvl (which is then published to npm)

Uses create-react-app setup for display demo application

## Demos & Examples

[Search at Frontend-Devtools-Portal](https://zimfrontendcoordination.github.io/zimFrontendDocuClient/#/)

- take a look at src/demo/index.tsx: via npm run start you may start the dev setup from create-react-app (but there need to be two changes made to the tsconfig.json)
react-scripts will print necessary adaptions to console. (change baseUrl + noEmit to true) 


## Quickstart

```ts

// import component and optionally select type
import { ZIMFuzzySearch, ZIMSearchAble } from "zim-fuzzysearch"

// call component and pass in data
const Demo = () => {
  return 
    (<ZIMFuzzySearch.Comp
        data={
          [{
            label: "Nym weichsel vnd thu sy In ein haff",
            value: "-",
            tag: "b2.1",
          }]
        }
        onSelect={
          // what shoukd happen when result link is clicked
          // callback gets passed in selected ZimSearchable object 
          (selected) => console.log(selected)
        }/>)
}


```


## External Dependencies

- Component has __bootstrap4__ and __font-awesome6__ classnames assigned BUT NOT bundled into. Apply external dependencies if needed.


## Advanced

```js

// ... return for rendering: 
// (how to import see quickstart)

<ZIMFuzzySearch.Comp 
  data={testData.coremaData}
  // configure fuse.js options
  fuseOptions={{
    keys: ["label", "tag"] // keys is required! adjusts where fuse.js should look for data to index
                           // other properties are directly from fuse.js 
    //ignoreLocation: true, 
    //ignoreFieldNorm: true,
    //includeScore: false,
    }}

  // options to adjust mark.js behavior
  markOptions={{
    accuracy: "exactly",        // complementary will mark whole word 
    exclude: ["h5"],            // exclude elems in result from highlighting 
  }}
/>

```



# Contribute

## Useful Resources

- https://medium.com/@jchiam/publishing-a-typescript-react-component-to-npm-d3cc15b8d0a2
- https://itnext.io/step-by-step-building-and-publishing-an-npm-typescript-package-44fe7164964c


## Create react app and useful stuff:
- https://github.com/wmonk/create-react-app-typescript/blob/master/template/README.md#publishing-components-to-npm


## Important Scripts

```sh
# locally build publishable lib folder
# this folder will be published by npm publish later on
npm run npm:build

# login to npm before
npm login

# apply new version
npm version x.y.z

# then publish to npmjs 
npm publish

```